@@ -43,3 +43,10 @@
 #' LC_Spainmales
 #' }
 "SpainNat"
+#' @export
+print.CVmortalityData <- function(x, ...) {
+  cat("Mortality Data\n")
+  cat(x$label, "including", x$series ,"\n")
+  cat("Years", c(min(x$years),":", max(x$years)),"\n")
+  cat("Abridged Ages", c(min(x$ages),":", max(x$ages)), "\n")
+}
